.. _reference:

API reference
#############

If you are looking for the description of the models, views and more, you're
on the right place.

.. toctree::
    :maxdepth: 2
    
    reference/models
    reference/views
    reference/templatetags
    reference/templates
    reference/middleware
    reference/related_finders